@@ -1,5 +1,9 @@
+"""The pyrealm package.
+
+TODO: complete this documentation
+"""
+
 import os
-import sys
 import warnings
 
 # _ROOT = os.path.abspath(os.path.dirname(__file__))
@@ -8,12 +12,17 @@ import warnings
 # def get_data_path(path):
 #     return os.path.join(_ROOT, 'data', path)
 
+
 # Setup warnings to simpler one line warning
 
-def warning_on_one_line(message, category, filename, lineno, file=None, line=None):
-    
-    filename = os.path.join('pyrealm', os.path.basename(filename))
-    return '%s:%s: %s: %s\n' % (filename, lineno, category.__name__, message)
+
+def warning_on_one_line(
+    message: str, category: str, filename: str, lineno: int, file=None, line=None
+):
+    """Provide a simple one line warning for use in docstrings."""
+    filename = os.path.join("pyrealm", os.path.basename(filename))
+    return "%s:%s: %s: %s\n" % (filename, lineno, category.__name__, message)
+
 
 warnings.formatwarning = warning_on_one_line
 
@@ -28,4 +37,4 @@ warnings.formatwarning = warning_on_one_line
 #             return func(*args)
 #         finally:
 #             sys.stderr = stderr_bak
-#     return wrapper
\ No newline at end of file
+#     return wrapper
